@@ -2,3 +2,5 @@ from attlesnake.parameter.base import *
 from attlesnake.parameter.constants import *
 from attlesnake.parameter.direction_cosine_matrix import *
 from attlesnake.parameter.euler_angle import *
+from attlesnake.parameter.principal_rotation_vector import *
+from attlesnake.parameter.quaternion import *
