@@ -6,6 +6,7 @@ import numpy as np
 
 import attlesnake.parameter.base as base
 import attlesnake.parameter.euler_angle as euler_angle
+import attlesnake.parameter.quaternion as quaternion
 
 
 class DCM(base.BaseAttitudeParameter):
@@ -21,8 +22,22 @@ class DCM(base.BaseAttitudeParameter):
             # (i.e. that columns are orthonormal with determinant +1)
             self.array = np.array(array_3x3)
 
+    def __matmul__(self, other: "DCM") -> "DCM":
+        """DCM composition (real matrix multiplication)."""
+        return DCM(self.array @ other.array)
+
+    def __repr__(self):
+        return np.array_str(self.array, precision=4)
+
+    def inverse(self) -> "DCM":
+        """
+        Return the inverse DCM, without modifying the
+        original DCM.
+        """
+        return DCM(np.transpose(self.array))
+
     @classmethod
-    def from_321_euler_angles(
+    def from_ea321(
         cls, ea_321: "euler_angle.EulerAngle321"
     ) -> None:
         """
@@ -51,7 +66,7 @@ class DCM(base.BaseAttitudeParameter):
         return cls(array)
 
     @classmethod
-    def from_313_euler_angles(
+    def from_ea313(
         cls, ea_313: "euler_angle.EulerAngle313"
     ) -> "DCM":
         """
@@ -78,3 +93,24 @@ class DCM(base.BaseAttitudeParameter):
             ]
         ])
         return cls(array)
+
+    @classmethod
+    def from_quaternion(cls, q: "quaternion.Quaternion") -> "DCM":
+        array = np.array([
+            [
+                q.s**2 + q.v1**2 - q.v2**2 - q.v3**2,
+                2*(q.v1*q.v2 + q.s*q.v3),
+                2*(q.v1*q.v3 - q.s*q.v2)
+            ],
+            [
+                2*(q.v1*q.v2 - q.s*q.v3),
+                q.s**2 - q.v1**2 + q.v2**2 - q.v3**2,
+                2*(q.v2*q.v3 + q.s*q.v1)
+            ],
+            [
+                2*(q.v1*q.v3 + q.s*q.v2),
+                2*(q.v2*q.v3 - q.s*q.v1),
+                q.s**2 - q.v1**2 - q.v2**2 + q.v3**2
+            ]
+        ])
+        return cls(array)
